.. currentmodule:: sardana.tango.pool.IORegister

:mod:`~sardana.tango.pool.IORegister`
=========================================

.. automodule:: sardana.tango.pool.IORegister

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`IORegister`
    * :class:`IORegisterClass`

IORegister
--------------

.. inheritance-diagram:: IORegister
    :parts: 1
    
.. autoclass:: IORegister
    :show-inheritance:
    :members:
    :undoc-members:

IORegisterClass
-------------------

.. inheritance-diagram:: IORegisterClass
    :parts: 1
    
.. autoclass:: IORegisterClass
    :show-inheritance:
    :members:
    :undoc-members:

